==> react_image_annotate_ns_workflow-4.0.9.tgz: package/RegionLabel/index.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import CheckIcon from "@mui/icons-material/Check";
import TrashIcon from "@mui/icons-material/Delete";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import Button from "@mui/material/Button";
import IconButton from "@mui/material/IconButton";
import Paper from "@mui/material/Paper";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import TextField from "@mui/material/TextField";
import { makeStyles } from "@mui/styles";
import classnames from "classnames";
import isEqual from "lodash/isEqual";
import React, { memo, useRef } from "react";
import CreatableSelect from "react-select/creatable";
import styles from "./styles";

// import { getIn, setIn } from "seamless-immutable"

import { asMutable } from "seamless-immutable";
import LocalStorage from "../Components/LocalStorage.js";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return styles;
});
export var RegionLabel = function RegionLabel(_ref) {
  var _asMutable, _asMutable2, _asMutable3;
  var region = _ref.region,
    editing = _ref.editing,
    allowedClasses = _ref.allowedClasses,
    allowedTags = _ref.allowedTags,
    onDelete = _ref.onDelete,
    _onChange = _ref.onChange,
    onClose = _ref.onClose,
    onOpen = _ref.onOpen,
    onRegionClassAdded = _ref.onRegionClassAdded,
    onRegionTagAdded = _ref.onRegionTagAdded,
    allowComments = _ref.allowComments,
    invalid_show = _ref.invalid_show,
    delete_annotation = _ref.delete_annotation,
    setdelete_annotation = _ref.setdelete_annotation,
    isReadingMode = _ref.isReadingMode,
    isImageMode = _ref.isImageMode,
    regions = _ref.regions,
    state = _ref.state,
    onInvalidRegion = _ref.onInvalidRegion;
  var classes = useStyles();
  var commentInputRef = useRef(null);
  var onCommentInputClick = function onCommentInputClick(_) {
    // The TextField wraps the <input> tag with two divs
    var commentInput = commentInputRef.current.children[0].children[0];
    if (commentInput) return commentInput.focus();
  };
  var visible_fields = LocalStorage.get_visible_fields();
  var error_message = isEqual((_asMutable = asMutable((region === null || region === void 0 ? void 0 : region.tags) || [])) === null || _asMutable === void 0 ? void 0 : _asMutable.sort(), (_asMutable2 = asMutable((region === null || region === void 0 ? void 0 : region.invalid_tag) || [])) === null || _asMutable2 === void 0 ? void 0 : _asMutable2.sort());
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(Paper, {
    onClick: function onClick() {
      return !isReadingMode && (!editing ? onOpen(region) : null);
    },
    className: classnames(classes.regionInfo, {
      highlighted: region.highlighted
    }),
    style: {
      border: region.invalid ? region.update_user ? "1px solid green" : "1px solid red" : null
    }
  }, !editing ? /*#__PURE__*/React.createElement("div", {
    id: "image_annotation"
  }, region.cls && /*#__PURE__*/React.createElement("div", {
    className: "name"
  }, /*#__PURE__*/React.createElement("div", {
    className: "circle",
    style: {
      backgroundColor: region.color
    }
  }), region.cls), region.tags && /*#__PURE__*/React.createElement("div", {
    className: "tags"
  }, region.tags.map(function (t) {
    return /*#__PURE__*/React.createElement("div", {
      key: t,
      className: "tag"
    }, t);
  }))) : /*#__PURE__*/React.createElement("div", {
    style: {
      width: 200
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex",
      flexDirection: "row"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex",
      backgroundColor: region.color || "#888",
      color: "#fff",
      padding: 4,
      paddingLeft: 8,
      paddingRight: 8,
      borderRadius: 4,
      fontWeight: "bold",
      textShadow: "0px 0px 5px rgba(0,0,0,0.4)"
    }
  }, region.type), /*#__PURE__*/React.createElement("div", {
    style: {
      flexGrow: 1
    }
  }), /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      var delet_arr = _toConsumableArray(delete_annotation);
      delet_arr.push(region);
      var filterArr = delet_arr && delet_arr.filter(function (arr, index, self) {
        return index === self.findIndex(function (t) {
          return t.id === arr.id && arr.id;
        });
      }).map(function (item) {
        return item;
      });
      setdelete_annotation(filterArr);
      onDelete(region);
    },
    tabIndex: -1,
    style: {
      width: 22,
      height: 22
    },
    size: "small",
    variant: "outlined"
  }, /*#__PURE__*/React.createElement(TrashIcon, {
    style: {
      marginTop: -8,
      width: 16,
      height: 16
    }
  })), invalid_show && region.cls && /*#__PURE__*/React.createElement(IconButton, {
    tabIndex: -1,
    style: {
      width: 22,
      height: 22
    },
    size: "small",
    variant: "outlined"
  }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
    style: {
      color: (region === null || region === void 0 ? void 0 : region.invalid) ? "#faad14" : "grey",
      marginTop: -8,
      width: 16,
      height: 16
    },
    onClick: function onClick() {
      var invalid = !(region === null || region === void 0 ? void 0 : region.invalid);
      var obj = {};
      if (isImageMode) {
        obj = _objectSpread({}, region, {
          invalid: invalid
        });
      } else {
        obj = _objectSpread({}, region, {
          invalid: !(region === null || region === void 0 ? void 0 : region.invalid),
          invalid_tag: !(region === null || region === void 0 ? void 0 : region.invalid) ? region.tags : []
        });
      }
      onInvalidRegion(obj);
    }
  }))), (allowedClasses || []).length > 0 && /*#__PURE__*/React.createElement("div", {
    style: {
      marginTop: 6
    }
  }, /*#__PURE__*/React.createElement(CreatableSelect
  // menuShouldBlockScroll={true}
  , {
    menuPosition: "fixed",
    menuPlacement: "auto",
    placeholder: "Classification",
    onChange: function onChange(o, actionMeta) {
      if (actionMeta.action === "create-option") {
        onRegionClassAdded(o.value);
        window.customEntity(o.value);
      }
      if (o.value && o.value !== region.cls && !invalid_show && (region === null || region === void 0 ? void 0 : region.invalid)) {
        return _onChange(_objectSpread({}, region, {
          cls: o.value,
          update_user: true
        }));
      } else {
        return _onChange(_objectSpread({}, region, {
          cls: o.value,
          update_user: false
        }));
      }
    },
    value: region.cls ? {
      label: region.cls,
      value: region.cls
    } : null,
    options: isImageMode ? asMutable(allowedClasses.map(function (c) {
      return {
        value: c,
        label: c
      };
    }).filter(function (_ref2) {
      var id1 = _ref2.value;
      return !(visible_fields === null || visible_fields === void 0 ? void 0 : visible_fields.includes(id1)) && !(regions === null || regions === void 0 ? void 0 : regions.some(function (_ref3) {
        var id2 = _ref3.cls;
        return id2 === id1;
      }));
    }) // roles.filter(({ value: id1 }) => !fields.roles.some(({ role: id2 }) => id2 === id1))
    ) : asMutable(allowedClasses.map(function (c) {
      return {
        value: c,
        label: c
      };
    }))
  })), (allowedTags || []).length > 0 && /*#__PURE__*/React.createElement("div", {
    style: {
      marginTop: 4
    }
  }, /*#__PURE__*/React.createElement(CreatableSelect
  // menuShouldBlockScroll={true}
  , {
    menuPosition: "fixed",
    menuPlacement: "auto",
    onChange: function onChange(newTags, prev) {
      if (prev.action === "create-option") {
        var _newTags$find;
        onRegionTagAdded(newTags === null || newTags === void 0 ? void 0 : (_newTags$find = newTags.find(function (item) {
          return item.__isNew__ === true;
        })) === null || _newTags$find === void 0 ? void 0 : _newTags$find.value);
      }
      if (!invalid_show && (region === null || region === void 0 ? void 0 : region.invalid) && !error_message) {
        var _newTags$map;
        _onChange(_objectSpread({}, region, {
          tags: (newTags === null || newTags === void 0 ? void 0 : newTags.length) ? newTags.map(function (t) {
            return t.value;
          }) : [],
          tag_count: (newTags === null || newTags === void 0 ? void 0 : newTags.length) ? (_newTags$map = newTags.map(function (t) {
            return t.value;
          })) === null || _newTags$map === void 0 ? void 0 : _newTags$map.length : 0,
          update_user: true
        }));
      } else {
        var _newTags$map2;
        _onChange(_objectSpread({}, region, {
          tags: (newTags === null || newTags === void 0 ? void 0 : newTags.length) ? newTags.map(function (t) {
            return t.value;
          }) : [],
          tag_count: (newTags === null || newTags === void 0 ? void 0 : newTags.length) ? (_newTags$map2 = newTags.map(function (t) {
            return t.value;
          })) === null || _newTags$map2 === void 0 ? void 0 : _newTags$map2.length : 0
        }));
      }
    },
    placeholder: "Tags",
    value: (region.tags || []).map(function (c) {
      return {
        label: c,
        value: c
      };
    }),
    isMulti: true,
    options: asMutable(allowedTags.map(function (c) {
      return {
        value: c,
        label: c
      };
    }))
  })), !invalid_show && error_message && ((_asMutable3 = asMutable((region === null || region === void 0 ? void 0 : region.tags) || [])) === null || _asMutable3 === void 0 ? void 0 : _asMutable3.length) ? /*#__PURE__*/React.createElement("span", null, "Enter correct data, this is marked invalid") : null, allowComments && /*#__PURE__*/React.createElement(TextField, {
    InputProps: {
      className: classes.commentBox
    },
    fullWidth: true,
    multiline: true,
    rows: 3,
    ref: commentInputRef,
    onClick: onCommentInputClick,
    value: region.comment || "",
    onChange: function onChange(event) {
      return _onChange(_objectSpread({}, region, {
        comment: event.target.value
      }));
    }
  }), onClose && /*#__PURE__*/React.createElement("div", {
    style: {
      marginTop: 4,
      display: "flex"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      flexGrow: 1
    }
  }), /*#__PURE__*/React.createElement(Button, {
    onClick: function onClick() {
      onClose(region);
    },
    size: "small",
    variant: "contained",
    color: "primary"
  }, /*#__PURE__*/React.createElement(CheckIcon, null))))));
};
export default memo(RegionLabel, function (prevProps, nextProps) {
  return prevProps.editing === nextProps.editing && prevProps.region === nextProps.region;
});

==> react_image_annotate_ns_workflow-5.0.0.tgz: package/RegionLabel/index.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";
import CheckIcon from "@mui/icons-material/Check";
import TrashIcon from "@mui/icons-material/Delete";
import WarningAmberIcon from "@mui/icons-material/WarningAmber";
import Button from "@mui/material/Button";
import IconButton from "@mui/material/IconButton";
import Paper from "@mui/material/Paper";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import TextField from "@mui/material/TextField";
import { makeStyles } from "@mui/styles";
import classnames from "classnames";
import isEqual from "lodash/isEqual";
import React, { memo, useRef } from "react";
import CreatableSelect from "react-select/creatable";
import styles from "./styles";

// import { getIn, setIn } from "seamless-immutable"

import { asMutable } from "seamless-immutable";
import LocalStorage from "../Components/LocalStorage.js";
var theme = createTheme();
var useStyles = makeStyles(function (theme) {
  return styles;
});
export var RegionLabel = function RegionLabel(_ref) {
  var _asMutable, _asMutable2, _asMutable3;
  var region = _ref.region,
    editing = _ref.editing,
    allowedClasses = _ref.allowedClasses,
    allowedTags = _ref.allowedTags,
    onDelete = _ref.onDelete,
    _onChange = _ref.onChange,
    onClose = _ref.onClose,
    onOpen = _ref.onOpen,
    onRegionClassAdded = _ref.onRegionClassAdded,
    onRegionTagAdded = _ref.onRegionTagAdded,
    allowComments = _ref.allowComments,
    invalid_show = _ref.invalid_show,
    delete_annotation = _ref.delete_annotation,
    setdelete_annotation = _ref.setdelete_annotation,
    isReadingMode = _ref.isReadingMode,
    isImageMode = _ref.isImageMode,
    regions = _ref.regions,
    state = _ref.state,
    onInvalidRegion = _ref.onInvalidRegion;
  var classes = useStyles();
  var commentInputRef = useRef(null);
  var onCommentInputClick = function onCommentInputClick(_) {
    // The TextField wraps the <input> tag with two divs
    var commentInput = commentInputRef.current.children[0].children[0];
    if (commentInput) return commentInput.focus();
  };
  var visible_fields = LocalStorage.get_visible_fields();
  var error_message = isEqual((_asMutable = asMutable((region === null || region === void 0 ? void 0 : region.tags) || [])) === null || _asMutable === void 0 ? void 0 : _asMutable.sort(), (_asMutable2 = asMutable((region === null || region === void 0 ? void 0 : region.invalid_tag) || [])) === null || _asMutable2 === void 0 ? void 0 : _asMutable2.sort());
  return /*#__PURE__*/React.createElement(ThemeProvider, {
    theme: theme
  }, /*#__PURE__*/React.createElement(Paper, {
    onClick: function onClick() {
      return !isReadingMode && (!editing ? onOpen(region) : null);
    },
    className: classnames(classes.regionInfo, {
      highlighted: region.highlighted
    }),
    style: {
      border: region.update_user ? "1px solid green" : region.invalid && "1px solid red"
    }
  }, !editing ? /*#__PURE__*/React.createElement("div", {
    id: "image_annotation"
  }, region.cls && /*#__PURE__*/React.createElement("div", {
    className: "name"
  }, /*#__PURE__*/React.createElement("div", {
    className: "circle",
    style: {
      backgroundColor: region.color
    }
  }), region.cls), region.tags && /*#__PURE__*/React.createElement("div", {
    className: "tags"
  }, region.tags.map(function (t) {
    return /*#__PURE__*/React.createElement("div", {
      key: t,
      className: "tag"
    }, t);
  }))) : /*#__PURE__*/React.createElement("div", {
    style: {
      width: 200
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex",
      flexDirection: "row"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex",
      backgroundColor: region.color || "#888",
      color: "#fff",
      padding: 4,
      paddingLeft: 8,
      paddingRight: 8,
      borderRadius: 4,
      fontWeight: "bold",
      textShadow: "0px 0px 5px rgba(0,0,0,0.4)"
    }
  }, region.type), /*#__PURE__*/React.createElement("div", {
    style: {
      flexGrow: 1
    }
  }), /*#__PURE__*/React.createElement(IconButton, {
    onClick: function onClick() {
      var delet_arr = _toConsumableArray(delete_annotation);
      delet_arr.push(region);
      var filterArr = delet_arr && delet_arr.filter(function (arr, index, self) {
        return index === self.findIndex(function (t) {
          return t.id === arr.id && arr.id;
        });
      }).map(function (item) {
        return item;
      });
      setdelete_annotation(filterArr);
      onDelete(region);
    },
    tabIndex: -1,
    style: {
      width: 22,
      height: 22
    },
    size: "small",
    variant: "outlined"
  }, /*#__PURE__*/React.createElement(TrashIcon, {
    style: {
      marginTop: -8,
      width: 16,
      height: 16
    }
  })), invalid_show && region.cls && /*#__PURE__*/React.createElement(IconButton, {
    tabIndex: -1,
    style: {
      width: 22,
      height: 22
    },
    size: "small",
    variant: "outlined"
  }, /*#__PURE__*/React.createElement(WarningAmberIcon, {
    style: {
      color: (region === null || region === void 0 ? void 0 : region.invalid) ? "#faad14" : "grey",
      marginTop: -8,
      width: 16,
      height: 16
    },
    onClick: function onClick() {
      var invalid = !(region === null || region === void 0 ? void 0 : region.invalid);
      var obj = {};
      if (isImageMode) {
        obj = _objectSpread({}, region, {
          invalid: invalid
        });
      } else {
        obj = _objectSpread({}, region, {
          invalid: !(region === null || region === void 0 ? void 0 : region.invalid),
          invalid_tag: !(region === null || region === void 0 ? void 0 : region.invalid) ? region.tags : []
        });
      }
      onInvalidRegion(obj);
    }
  }))), (allowedClasses || []).length > 0 && /*#__PURE__*/React.createElement("div", {
    style: {
      marginTop: 6
    }
  }, /*#__PURE__*/React.createElement(CreatableSelect
  // menuShouldBlockScroll={true}
  , {
    menuPosition: "fixed",
    menuPlacement: "auto",
    placeholder: "Classification",
    onChange: function onChange(o, actionMeta) {
      if (actionMeta.action === "create-option") {
        onRegionClassAdded(o.value);
        window.customEntity(o.value);
      }
      if (o.value && o.value !== region.cls && !invalid_show && (region === null || region === void 0 ? void 0 : region.invalid)) {
        return _onChange(_objectSpread({}, region, {
          cls: o.value,
          update_user: true
        }));
      } else {
        return _onChange(_objectSpread({}, region, {
          cls: o.value,
          update_user: false
        }));
      }
    },
    value: region.cls ? {
      label: region.cls,
      value: region.cls
    } : null,
    options: isImageMode ? asMutable(allowedClasses.map(function (c) {
      return {
        value: c,
        label: c
      };
    }).filter(function (_ref2) {
      var id1 = _ref2.value;
      return !(visible_fields === null || visible_fields === void 0 ? void 0 : visible_fields.includes(id1)) && !(regions === null || regions === void 0 ? void 0 : regions.some(function (_ref3) {
        var id2 = _ref3.cls;
        return id2 === id1;
      }));
    }) // roles.filter(({ value: id1 }) => !fields.roles.some(({ role: id2 }) => id2 === id1))
    ) : asMutable(allowedClasses.map(function (c) {
      return {
        value: c,
        label: c
      };
    }))
  })), (allowedTags || []).length > 0 && /*#__PURE__*/React.createElement("div", {
    style: {
      marginTop: 4
    }
  }, /*#__PURE__*/React.createElement(CreatableSelect
  // menuShouldBlockScroll={true}
  , {
    menuPosition: "fixed",
    menuPlacement: "auto",
    onChange: function onChange(newTags, prev) {
      if (prev.action === "create-option") {
        var _newTags$find;
        onRegionTagAdded(newTags === null || newTags === void 0 ? void 0 : (_newTags$find = newTags.find(function (item) {
          return item.__isNew__ === true;
        })) === null || _newTags$find === void 0 ? void 0 : _newTags$find.value);
      }
      if (!invalid_show && (region === null || region === void 0 ? void 0 : region.invalid) && !error_message) {
        var _newTags$map;
        _onChange(_objectSpread({}, region, {
          tags: (newTags === null || newTags === void 0 ? void 0 : newTags.length) ? newTags.map(function (t) {
            return t.value;
          }) : [],
          tag_count: (newTags === null || newTags === void 0 ? void 0 : newTags.length) ? (_newTags$map = newTags.map(function (t) {
            return t.value;
          })) === null || _newTags$map === void 0 ? void 0 : _newTags$map.length : 0,
          update_user: true
        }));
      } else {
        var _newTags$map2;
        _onChange(_objectSpread({}, region, {
          tags: (newTags === null || newTags === void 0 ? void 0 : newTags.length) ? newTags.map(function (t) {
            return t.value;
          }) : [],
          tag_count: (newTags === null || newTags === void 0 ? void 0 : newTags.length) ? (_newTags$map2 = newTags.map(function (t) {
            return t.value;
          })) === null || _newTags$map2 === void 0 ? void 0 : _newTags$map2.length : 0
        }));
      }
    },
    placeholder: "Tags",
    value: (region.tags || []).map(function (c) {
      return {
        label: c,
        value: c
      };
    }),
    isMulti: true,
    options: asMutable(allowedTags.map(function (c) {
      return {
        value: c,
        label: c
      };
    }))
  })), !invalid_show && error_message && ((_asMutable3 = asMutable((region === null || region === void 0 ? void 0 : region.tags) || [])) === null || _asMutable3 === void 0 ? void 0 : _asMutable3.length) ? /*#__PURE__*/React.createElement("span", null, "Enter correct data, this is marked invalid") : null, allowComments && /*#__PURE__*/React.createElement(TextField, {
    InputProps: {
      className: classes.commentBox
    },
    fullWidth: true,
    multiline: true,
    rows: 3,
    ref: commentInputRef,
    onClick: onCommentInputClick,
    value: region.comment || "",
    onChange: function onChange(event) {
      return _onChange(_objectSpread({}, region, {
        comment: event.target.value
      }));
    }
  }), onClose && /*#__PURE__*/React.createElement("div", {
    style: {
      marginTop: 4,
      display: "flex"
    }
  }, /*#__PURE__*/React.createElement("div", {
    style: {
      flexGrow: 1
    }
  }), /*#__PURE__*/React.createElement(Button, {
    onClick: function onClick() {
      onClose(region);
    },
    size: "small",
    variant: "contained",
    color: "primary"
  }, /*#__PURE__*/React.createElement(CheckIcon, null))))));
};
export default memo(RegionLabel, function (prevProps, nextProps) {
  return prevProps.editing === nextProps.editing && prevProps.region === nextProps.region;
});
